==> haskell-tamarin-prover-term-1.2.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.2.2
id: tamarin-prover-term-1.2.2-8tQWtfWLYo3L7YOtQH89n6
key: tamarin-prover-term-1.2.2-8tQWtfWLYo3L7YOtQH89n6
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
abi: d51f7ef8cf6411e39d924c9d86a2cd7f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-term-1.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-term-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tamarin-prover-term-1.2.2
hs-libraries: HStamarin-prover-term-1.2.2-8tQWtfWLYo3L7YOtQH89n6
depends:
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j base-4.10.0.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 process-1.6.1.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1
abi-depends: HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1=280a465b2c87b17d4f0b717078e5cdf4
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-term-1.2.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.2.2
id: tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1
key: tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
abi: 412aedeaab51d398f916a26ef52210a9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-term-1.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-term-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tamarin-prover-term-1.2.2
hs-libraries: HStamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1
depends:
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 process-1.6.1.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1
abi-depends: HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1=280a465b2c87b17d4f0b717078e5cdf4
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
